# Table of Contents

- [virtual-workspaces](<./virtual-workspaces.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Virtual Workspaces](<./Virtual-Workspaces.md>)
  - [Overview](<./Virtual-Workspaces/Overview.md>)
  - [Essentials](<./Virtual-Workspaces/Essentials.md>)
  - [Access Control for Virtual Workspaces](<./Virtual-Workspaces/Access-Control-for-Virtual-Workspaces.md>)
  - [Access Control Behavior for Different User Roles](<./Virtual-Workspaces/Access-Control-Behavior-for-Different-User-Roles.md>)
  - [User Flow for an Admin Creating a New Fact Sheet](<./Virtual-Workspaces/User-Flow-for-an-Admin-Creating-a-New-Fact-Sheet.md>)
  - [User Flow for a Member Creating a New Fact Sheet](<./Virtual-Workspaces/User-Flow-for-a-Member-Creating-a-New-Fact-Sheet.md>)
